@@ -17,7 +17,7 @@ File::LoadLines - Load lines from files and network
 
 =cut
 
-our $VERSION = '1.042';
+our $VERSION = '1.043';
 
 =head1 SYNOPSIS
 
@@ -149,7 +149,7 @@ sub loadlines {
     }
     elsif ( $filename eq '-' ) {
 	$filename = "__STDIN__";
-	binmode( $filename, ':raw' );
+	binmode( STDIN, ':raw' );
 	$data = do { local $/; <STDIN> };
     }
     elsif ( $filename =~ /^https?:/ ) {
